@@ -13,7 +13,17 @@
 ## Author: Andrew Hooker
 
 ones <- function(dim1,dim2=NULL){
-    if(is.null(dim2)) dim2 <- dim1
-    mat <- matrix(1,dim1,dim2)
-    return(mat)
+  if(is.null(dim2)){
+    if(length(dim1)==2){
+      tmp <- dim1
+      dim1 <- tmp[1]
+      dim2 <- tmp[2]
+    } else if(length(dim1)==1){
+      dim2 <- dim1
+    } else {
+      stop("first argument can only have one or two values")
+    }
+  }
+  mat <- matrix(1,dim1,dim2)
+  return(mat)
 }
