@@ -1,9 +1,6 @@
 
-# should give a warning
-output <- a_line_search(poped.db)
-
 # very sparse grid to evaluate (4 points for each design valiable)
-output <- a_line_search(poped.db,opt_xt=TRUE,ls_step_size=4)
+output <- a_line_search(poped.db, opt_xt=TRUE, opt_a=TRUE, ls_step_size=4)
 
 \dontrun{  
   
